# frozen_string_literal: true

require "listen"
require "gotta/mod/version"
require "gotta/mod/monkey_patch"
require "gotta/mod/project"
require "gotta/mod/event"
require "gotta/mod/listener"
require "gotta/mod/hub"
require "gotta/mod/mod_builder"
require 'pry'
module Gotta
  module Mod
    class Error < StandardError; end

    def self.hub=(hub_instance)
      @@hub = hub_instance
    end

    def self.hub
      @@hub
    end

    def self.now(dir: Dir.pwd)
      project = Gotta::Project.new(dir)
      Gotta::Project.config = project
      listener = Listener.new(working_directory: dir)
      self.hub = Hub.new(listener.queue)
      hub_thread = Thread.new {hub.start} # Hub runs on a separate thread.
      # Now require all `main.rb` files inside the mods folder
      Dir.glob("#{project.mods_dir}/*") do |f|
        rbfile = "#{f}/#{File.basename(f)}.rb"
        ModBuilder.class_eval(File.read(rbfile), rbfile)
      end
      hub.check_dependencies
      listener.start
      puts "Ready for action."
      sleep
    end
  end
end
