# frozen_string_literal: true

module Gotta
  module Mod
    class Event
      attr_reader :type,
                  :filename,
                  :absolute_path,
                  :path,
                  :working_directory

      def initialize(type:, absolute_path:, working_directory:)
        @working_directory = working_directory
        @absolute_path = absolute_path
        @path = relative_path_for(@absolute_path.dup)
        @filename = File.basename(@absolute_path)
        @type = type
        make_it_immutable
      end

      def added?
        @type == :added
      end

      def modified?
        @type == :modified
      end

      def removed?
        @type == :removed
      end

      private
      def relative_path_for(pth)
        pth.slice!("#{working_directory}/")
        pth
      end

      def make_it_immutable
        freeze
      end
    end
  end
end