# frozen_string_literal: true

module Gotta
  module Mod
    class Listener
      attr_reader :listener, :working_directory, :queue
      def initialize(working_directory:)
        @working_directory = working_directory
        @queue = Queue.new
        @listener = ::Listen.to(working_directory, &callback)
      end

      def start
        listener.start
      end

      def stop
        listener.stop
      end

      def callback
        Proc.new do |modified, added, removed|
          begin
            modified.each do |file|
              queue.push Event.new(type: :modified,
                                   absolute_path: file,
                                   working_directory: working_directory)
            end
            added.each do |file|
              queue.push Event.new(type: :added,
                                   absolute_path: file,
                                   working_directory: working_directory)
            end
            removed.each do |file|
              queue.push Event.new(type: :removed,
                                   absolute_path: file,
                                   working_directory: working_directory)
            end
          rescue StandardError => e
            puts e.full_message
            next
          end
        end
      end
    end
  end
end