# frozen_string_literal: true

module Gotta
  module Mod
    class ModBuilder

      def self.mod(name, &block)
        new(name: name, &block)
      end

      attr_reader   :name,
                    :description,
                    :version

      def initialize(name:, &block)
        @name = name
        instance_eval(&block)
        Mod.hub.loaded_mods << name
        puts "Mod '#{name}' registered."
      end

      def version(ver)
        @version = ver
      end

      def description(desc)
        @description = desc
      end

      def depends_on(mod_name)
        Mod.hub.add_dependency({self.name => mod_name})
      end

      def on(type, &block)
        Mod.hub.register_mod(
          mod_name: name,
          path: @filter,
          on: type,
          &block
        )
      end

      def watch(filter, &block)
        @filter = filter
        instance_eval &block
      end
    end
  end
end