# frozen_string_literal: true

module Gotta
  require "yaml"
  require "ostruct"
  class Project < OpenStruct
    class << self
      attr_accessor :config
    end

    attr_reader :dir, :config, :config_file_path
    def initialize(dir)
      @dir = dir
      @config_file_path = "#{dir}/project.yml"
      @config = read_config
      @config["project"]["mods_dir"] ||= "mods"
      @config["project"]["components_dir"] ||= @config["project"]["functions_dir"] || "components"
      @config["project"]["public_dir"] ||= "public"
      check_mods_dir
      super(@config['project'])
    end

    private

    def check_mods_dir
      Dir.mkdir(@config["project"]["mods_dir"]) unless File.directory?(@config["project"]["mods_dir"])
    end

    def read_config #=> {}
      load_file || {}
    end

    def load_file
      return nil unless File.file?(config_file_path)
      YAML.load(File.read(config_file_path)) rescue nil
    end
  end
end